@@ -9,6 +9,8 @@
 
 #pragma once
 
+#define BOOST_UBLAS_NO_STD_CERR
+
 #include <time.h>
 #include <algorithm>
 #include <math.h>
@@ -19,6 +21,7 @@
 #include <boost/numeric/ublas/matrix.hpp>
 #include <boost/numeric/ublas/lu.hpp>
 #include <boost/numeric/ublas/io.hpp>
+#include <boost/random/linear_congruential.hpp>
 #include <boost/random.hpp>
 
 using namespace std;
@@ -32,17 +35,34 @@ using namespace std;
 #include "ProjectionDepth.h"
 #include "Common.h"
 
-#ifndef VStudio
-#include <Rcpp.h> 
-using namespace Rcpp;
 
-#include <Rcpp/stats/random/runif.h>
-static Rcpp::stats::UnifGenerator rndm;
-#define ran(x) x*rndm()
+static boost::random::rand48 rEngine;
+static boost::random::normal_distribution<double> normDist;
 
-#else
-#define ran(x) rand()%x
+#define ran(x) rEngine()%x
+#define setseed(x) rEngine.seed(x)
 
-#endif
+//#ifndef _MSC_VER
+////#include <Rcpp.h> 
+////using namespace Rcpp;
+//#include <Rmath.h> 
+//
+////#include <Rcpp/stats/random/runif.h>
+////static Rcpp::stats::UnifGenerator rndm;
+//#define ran(x) ((int)runif(0,x))
+//
+//
+//#define setseed(x) set_seed(x,x)
+//
+//#include <Rcpp.h> 
+//using namespace Rcpp;
+//
+//#else
+//#define ran(x) rand()%x
+//
+//#define setseed(x) srand(x)
+//
+//#endif
 
 int random(int x);
+
